package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!`````"(```````!``````````&`!`0``
M`````@```$``.``)`$``%P`6``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0```!<`@``````
M`%P"````````7`(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````.RP````````[+``````````
M``$```````$````&````(/L````````@^P$``````"#[`0``````8`4`````
M``"X!0```````````0```````@````8````P^P```````##[`0``````,/L!
M`````````@`````````"````````"``````````$````!````#@"````````
M.`(````````X`@```````"0`````````)``````````$`````````%#E=&0$
M````\*D```````#PJ0```````/"I````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````"#[````````(/L!```````@^P$`
M`````.`$````````X`0````````!``````````0````4`````P```$=.50#;
M9]8+[F8!;&8L_95Z-1I=EQ'5#"]L:6(O;&0M;75S;"UP;W=E<G!C-C1L92YS
M;RXQ`````````!$```!'````!`````@````@$!``!4`$@"@`$`2`A@"$@J$`
M`@D`!`F(@!A!N@0""`````!'````2P```$\```!0````5P```%@```!9````
M`````%L```!<`````````%T```!>````8```````````````SMY'+6[%WQ]J
M?YI\Z]/O#B[%F[:XC?$.(/_D#M5DU'S9<5@<L@&+;YA/PYO"Y3\L0OK7A_JA
M;&"ZXY)\XT?&`57#/-)GK\QFB`=PTT-%U>PS8MOM%8PES'^IG)O@IP(*:QJ>
M4*/@^TD```````````````````````````````````````````,`"``X&```
M``````````````````````,`$P````(`````````````````H@$``!)@````
M````````````````````60```!)@````````````````````````=@$``!)@
M````````````````````````/0```!(`````````````````````````(`$`
M`!)@````````````````````````Y0$``!)@````````````````````````
ML0```!)@````````````````````````N@```"(`````````````````````
M````/P$``!(`````````````````````````R@$``!)@````````````````
M````````:P(``!)@````````````````````````AP$``!)@````````````
M`````````````P$``!)@````````````````````````?0(``!)@````````
M````````````````O@(``"$`````````````````````````-P```!)@````
M````````````````````O0(``!$`````````````````````````O0$``!$`
M````````````````````````+@$``!(`````````````````````````5`(`
M`!)@````````````````````````:0```!)@````````````````````````
M!`(``!)@````````````````````````OP(``!$`````````````````````
M````H@```!)@````````````````````````*P(``!)@````````````````
M````````'P```"``````````````````````````5`$``!)@````````````
M````````````Y````"``````````````````````````O`(``"$`````````
M````````````````<0```!)@````````````````````````_@```!)@````
M````````````````````80```!(`````````````````````````4@```!)@
M````````````````````````$````!)@````````````````````````(@(`
M`!)@````````````````````````E`(``!)@````````````````````````
ME@$``!)@````````````````````````@````"``````````````````````
M````C0(``!)@````````````````````````1`(``!)@````````````````
M````````2P```!(`````````````````````````\0$``!)@````````````
M`````````````0```!)@````````````````````````1````!(`````````
M````````````````Z@,``!)@````````````````````````-@(``!)@````
M````````````````````A0(``!)@````````````````````````"0```!$`
M````````````````````````$@(``!)@````````````````````````<@``
M`!)@````````````````````````<@(``!)@````````````````````````
M&````!)@````````````````````````"0$``!(`````````````````````
M````WP```!)@````````````````````````8P$``!8`````````````````
M````````FP(``!)@````````````````````````J@(``!)@````````````
M````````````)P$``!(`````````````````````````G````!)@````````
M````````````````J@```!)@````````````````````````=P```!)@````
M````````````````````1@$``!)@````````````````````````7P(``!)@
M````````````````````````&@$``!)@````````````````````````R0``
M`"``````````````````````````VP$``!)@````````````````````````
MH0```!)@````````````````````````X`$``!)@````````````````````
M````<@,``!)@"0#`/@```````!`)````````?P,``!)@"0#`2@```````%@!
M````````MP(``!)@"0!@'P```````*`"````````MP$``!)@"@`T:```````
M`!``````````]@(``!)@"0!P+0```````!@`````````]@,``!)@"``X&```
M`````!``````````*P,``!)@"0"0+0```````'0$````````0`,``!)@"0#0
M1P```````.0"````````BP,``!``%`"```(`````````````````$0,``!)@
M"0!0.@```````)P`````````.`,``!)@"0#P.@```````&0`````````5@,`
M`!)@"0``+````````&``````````9P,``!)@"0`@8P```````/@!````````
MEP,``!)@"0"@/0```````"`!````````Q@,``!``%`#8``(`````````````
M````RP,``!)@"0`0,@```````&``````````7@,``!)@"0`L(@```````&``
M````````'P,``!)@"0!P,@```````.P!````````!P,``!$`$P!X``(`````
M``@`````````OP,``!``$P"```(`````````````````D`,``!(`"0``(@``
M````````````````\P,``!)@"0"`8@```````)0`````````V`,``!)@"0!0
M/0```````$P`````````J0,``!)@"0!@+`````````@!````````_`,``!)@
M"0`@90```````/0!````````Z0(``!)@"0!@-````````.P%`````````&]P
M96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`%]?9&5R96=I<W1E<E]F<F%M
M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM
M;W9E`'-T<FYC;7``<W1R<F-H<@!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C:'(`<F5A9&QI
M;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E
M;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O7W5N
M9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H
M<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`')E861D:7(`<W!R:6YT9@!S=')D=7``<W1R=&]K`'!T:')E861?871F
M;W)K`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L
M:6)C+FUU<VPM<'!C-C1L92YS;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N
M=%]E>&5C`&UY7W!A<E]P;`!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A
M<E]F:6YD<')O9P!P87)?9&EE`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I
M;FET`%]S=&%R=%]C`'-H85]U<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A
M;G5P`%]?8G-S7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!?961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%```````@^P$``````!8`````````\",`
M```````H^P$``````!8`````````8",```````````(``````!8`````````
M```"```````8``(``````!8`````````*&P````````@``(``````!8`````
M````N&@````````P``(``````!8`````````J&D````````X``(``````!8`
M````````"&P```````!```(``````!8`````````$&P```````!(``(`````
M`!8`````````&&P```````!0``(``````!8`````````(&P```````!@``(`
M`````!8`````````\&L```````!H``(``````!8`````````^&L```````!X
M``(``````!8`````````,&P````````(_P$``````"8````H````````````
M```0_P$``````"8````>```````````````8_P$``````"8````*````````
M```````@_P$``````"8````<```````````````H_P$``````"8```!#````
M```````````P_P$``````"8````9```````````````X_P$``````"8````J
M``````````````!`_P$``````"8````R``````````````!(_P$``````"8`
M```L``````````````!0_P$``````"8````%``````````````!8_P$`````
M`"8````4``````````````!@_P$``````$D````Y``````````````!`_0$`
M`````!4````#``````````````!(_0$``````!4````$``````````````!0
M_0$``````!4````&``````````````!8_0$``````!4````'````````````
M``!@_0$``````!4````(``````````````!H_0$``````!4````)````````
M``````!P_0$``````!4````*``````````````!X_0$``````!4````+````
M``````````"`_0$``````!4````,``````````````"(_0$``````!4````-
M``````````````"0_0$``````!4````.``````````````"8_0$``````!4`
M```/``````````````"@_0$``````!4````0``````````````"H_0$`````
M`!4````2``````````````"P_0$``````!4````5``````````````"X_0$`
M`````!4````6``````````````#`_0$``````!4````7``````````````#(
M_0$``````!4````8``````````````#0_0$``````!4````:````````````
M``#8_0$``````!4````;``````````````#@_0$``````!4````<````````
M``````#H_0$``````!4````=``````````````#P_0$``````!4````@````
M``````````#X_0$``````!4````A````````````````_@$``````!4````B
M```````````````(_@$``````!4````C```````````````0_@$``````!4`
M```D```````````````8_@$``````!4````E```````````````@_@$`````
M`!4````F```````````````H_@$``````!4````G```````````````P_@$`
M`````!4````I```````````````X_@$``````!4````K``````````````!`
M_@$``````!4````M``````````````!(_@$``````!4````N````````````
M``!0_@$``````!4````O``````````````!8_@$``````!4````P````````
M``````!@_@$``````!4````Q``````````````!H_@$``````!4````S````
M``````````!P_@$``````!4````T``````````````!X_@$``````!4````U
M``````````````"`_@$``````!4````V``````````````"(_@$``````!4`
M```W``````````````"0_@$``````!4````X``````````````"8_@$`````
M`!4````Z``````````````"@_@$``````!4````[``````````````"H_@$`
M`````!4````\``````````````"P_@$``````!4````]``````````````"X
M_@$``````!4````^``````````````#`_@$``````!4````_````````````
M``#(_@$``````!4```!```````````````#0_@$``````!4```!!````````
M``````#8_@$``````!4```!"``````````````#@_@$``````!4```!#````
M``````````#H_@$``````!4```!$``````````````#P_@$``````!4```!%
M``````````````#X_@$``````!4```!&```````````````"`$P\R&9".*8"
M"'P0``'XX?\A^"``(3@0``'HI@,(?"``@$X`````&`!!^/__@CV@?HSII@.)
M?2`$@$X````````````````8`$'X__^"/=!^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]6'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CWX
M?HSII@.)?2`$@$X````````````````8`$'X__^"/<A^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]$'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW(?XSII@.)?2`$@$X````````````````8`$'X__^"/8!_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]^'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CT`?XSII@.)?2`$@$X````````````````8`$'X__^"/=!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]N'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU0?HSII@.)?2`$@$X````````````````8`$'X
M__^"/6!^C.FF`XE](`2`3@```````````````!@`0?C__X(]@'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CUH?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/7!_C.FF`XE](`2`3@```````````````!@`0?C__X(]*'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU`?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/>!_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]J'^,Z:8#B7T@!(!.````````````````&`!!^/__@CVP?XSII@.)?2`$
M@$X````````````````8`$'X__^"/5!_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]6'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW`?XSI
MI@.)?2`$@$X````````````````8`$'X__^"/8A_C.FF`XE](`2`3@``````
M`````````!@`0?C__X(],'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CTX?XSII@.)?2`$@$X````````````````8`$'X__^"/?!^C.FF`XE](`2`
M3@```````````````!@`0?C__X(]8'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CWP?XSII@.)?2`$@$X````````````````8`$'X__^"/9!^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]>'^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CUH?HSII@.)?2`$@$X````````````````8`$'X__^"
M/;!^C.FF`XE](`2`3@```````````````!@`0?C__X(]<'Z,Z:8#B7T@!(!.
M````````````````&`!!^/__@CV@?XSII@.)?2`$@$X````````````````8
M`$'X__^"/9A_C.FF`XE](`2`3@```````````````!@`0?C__X(]>'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CV8?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/>A^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M('^,Z:8#B7T@!(!.````````````````&`!!^/__@CWH?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/8A^C.FF`XE](`2`3@```````````````!@`
M0?C__X(]X'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU`?XSII@.)
M?2`$@$X````````````````8`$'X__^"/0A_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]V'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CVX
M?HSII@.)?2`$@$X````````````````8`$'X__^"/=A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]&'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CV0?XSII@.)?2`$@$X````````````````8`$'X__^"/<!^C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]J'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CU(?HSII@.)?2`$@$X````````````````8`$'X__^"/4A_
MC.FF`XE](`2`3@````````````````(`3#R@7T(XI@((?/#_P?OX_^'[$``!
M^&'_(?AX&VE\?`!A.'``@?AH`*'X<`"!.&@`H3A\`"&1\(\MZ8@`(?D``"`Y
MO?W_2Q@`0>@```!@2("BZ````&!0@&+H>"ND?$']_TL8`$'H````8%B`(ND`
M`.F+```?+'0!@D$```!@8(`BZ11J*7U\`.&#``!)Z00`?S@#`/\[M`=C?`H&
M*HDD'V-X`P`I80H&*IF5^?]+&`!!Z'P`@8!P``'I````8````&!X@>+H_O^B
M//[_0CW@[*4XP(%B^.CL2CEX&V9\`0`$+```*.D(`*/X$`#C^!@`0_D``"/Y
M@`&!0/__)#D$`$`Y(``I>:8#*7T4``!(````8````&````!@``!"8`D`Z.BT
M!TE])!\I>0$`2CDJ2>9\[/\`0@,`A#BT!X1\```@.0```&#0@6+H)!^$>+0'
MY7\``.`X*B$F??[_@CQ@K(0XG?W_2Q@`0>@```,LM`""00```&#0@6+HA`#!
M.V'Z_TL8`$'H>//$?W@;?WS^_V(\..IC.'$#`$@``",LF`""00```&#0@6+H
ME?S_2Q@`0>@-^/]+&`!!Z(@`0>GPCRWI>4I*?0``(#G``()`H``A.'C[XW\0
M``'H\/_!Z_C_X>NF`PA\(`"`3A7[_TL8`$'H````8```(RS0@6+X@`""0=WZ
M_TL8`$'H````8&"`(ND4:DE]``!*Z<8*ZIMD_O]+````8-"!8N@5_?]+&`!!
MZ$#__TL```!@R(%BZ```(RP,`()!(2D`2%C__TO^_V(\>//$?\#I8SBM`@!(
M````8```(RS(@6+X./^"0?DH`$@P__]+!`"`.,#^_TL!`&`XW?S_2Q@`0>BU
M^O]+&`!!Z``````````!@`(```(`3#P`74(X*`",@!1BA'QX"R-\Y`8A>```
M`#CA_P'XI@,(?!$``$@PV0$``@!,/-1<0CBF`@A\>!MI?/[_XCPTZ><X_O_"
M/#B9QCC^_V(\8*!C.````#D(`*DX$``!^.'_(?@"`(GH>?K_2Q@`0>@@`"$X
M$``!Z*8#"'P@`(!.``````````&`````````8`(`3#QP7$(X````8````&"`
M@6(X@($B.0`8*7P@`()-````8`B`@ND``"PL(`""3:8""'P0``'XX?\A^*8#
MB7T8`$'X(02`3A@`0>@@`"$X$``!Z*8#"'P@`(!.``!"8`(`3#P07$(X````
M8````&"`@6(X@(&".%`@@WQT'H1\=`Z$?)4!A'P@`()-````8!"`@ND``"PL
M(`""3:8""'P0``'XX?\A^*8#B7T8`$'X(02`3A@`0>@@`"$X$``!Z*8#"'P@
M`(!.````8```0F`"`$P\H%M".````&"`@2*)```)+"``@DRF`@A\$``!^.'_
M(?@```!@&(`BZ0``*2P4`()!````8`"!8N@E^?]+&`!!Z/7^_TL```!@((`B
MZ0``*2P4`()!_O]B/``L8S@A^O]+&`!!Z"``(3@!`"`Y````8!```>B`@2*9
MI@,(?"``@$X```!@````8```0F`"`$P\$%M".````&`H@"+I```I+#P`@D&F
M`@A\$``!^.'_(?@```!@_O]B/(B!@C@`+&,XG?;_2Q@`0>@@`"$X$``!Z*8#
M"'S`_O]+``!"8+C^_TL```!@````8````&````!@````8````&````!@`@!,
M/*!:0CC8_V'[^/_A^['_(?@```!@,(`BZ0``:>L``#LLY`""02``0?LP`('[
M>".:?'@;?'Q``,'[>!M^?```(XD```DLR`""03T`"2P0`()!`0`^C0``"2SP
M_X)`4/#<?P``^^L``#\LK`""0:8""'PX`*'[M`?>?WC;?7]@``'X````8```
M`&```$)@>//%?WCCA']X^^-_A?3_2Q@`0>@```,L$`""0*[P/WT]``DL/`""
M00D`_>L``#\LT/^"0&```>@@`$'K,`"!ZS@`H>M``,'KI@,(?%``(3AX^^-_
MV/]AZ_C_X>L@`(!.4.A[?P$`WCMT'GM_%/+_?P``>I/`__]+``#@.]#__TL`
M`,`[4/__2R``0>LP`('K0`#!Z[C__TL``````````8`&``````!@````8```
M0F`"`$P\8%E".*8""'SX_^'[$``!^#'_(?@H`($X\(\MZ;@`(?D``"`Y>!M_
M?!7V_TL8`$'H```#+$@`@D!``"&!)@0I50!`"2@0`()!__\J;0"@"BPP`()`
M>/OC?P(`@#A!\_]+&`!!Z#0`8WQ^V6-4%```2````&````!@``!"8```8#BX
M`$'I\(\MZ7E*2GT``"`YM`=C?!@`@D#0`"$X$``!Z/C_X>NF`PA\(`"`3E'V
M_TL8`$'H``````````&``0``````8````&```$)@`@!,/)!80CCP_\'[X?XA
M^'D;?GSPCRWI^``A^0``(#D0`()!```^B0``"2PD`()`^`!!Z?"/+>EY2DI]
M```@.8@!@D`@`2$X\/_!ZR``@$ZF`@A\&`'A^P@!H?LP`0'X,??_2Q@`0>AY
M&W]\'`&"07C[XW]]\?]+&`!!Z```(RSP`()!$P`CB1,`HSO2_RDY```)+!P`
M@D`!`#V)```)+-#_@D$```!@````8```0F`3`".)TO\I.0``"2SD`()!>//#
M?P`!@?NI\_]+&`!!Z'@;?'QXZZ-_F?/_2Q@`0>@4&GQ\`@!C.+0'8WQE]O]+
M&`!!Z/[_@CQXZZ9_>//%?V#IA#AX&WQ\B?3_2Q@`0>AH`($X>..#?]GR_TL8
M`$'H__\#+'CC@W\4`()!@``A@28$*54`0`DHB`""077V_TL8`$'H>..#?ZGQ
M_TL8`$'H>/OC?P`!@>N9\/]+&`!!Z```(RP@_X)`````8```0F!X^^-_??/_
M2Q@`0>AX\\-_4?7_2Q@`0>@P`0'H"`&AZQ@!X>NF`PA\F/[_2P``0F`!`#V)
MTO\I.0``"2P4_X)``@`]B0``"2RX_H)!!/__2TG^_TN`__]+I@((?``!@?L(
M`:'[&`'A^S`!`?A5]/]+&`!!Z``````````!@`0```(`3#R@5D(XI@((?-#_
M0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?A1_R'X\(\MZ6@`(?D``"`Y>!M_
M?```)(D]`"EI-``I?7[9*5442L1_>//#?RWR_TL8`$'H9`"!.'@;?'QX^^-_
MH?O_2WD;?7Q@`8)!#?+_2Q@`0>A`&#Q\$`&!0&8`8>L```!@,(!"ZR0?>WL`
M`#^)>/OJ?P``"2P<`()`%`(`2````&```$)@`0`JC0``"2P,`()!/0`)+/#_
M@D!04%]]M`=*?0(`?#@``+KK%%)C?(GT_TL8`$'H```C+"K9?7QL`()!```_
MB0``6NG_`"=Q*M@*?0``*)D@`()`O```2````&```$)@`0`_C?\`)W$!`"J9
MI`""03T`!RQX0PI]`0`(.>3_@D`]`"`Y___>.WA32'T``"J9`0`^C3X&*E4!
M`"B=```*+/#_@D!H`$'I\(\MZ7E*2GT``"`Y:`&"0+``(3@0``'HT/]!Z]C_
M8>O@_X'KZ/^AZ_#_P>OX_^'KI@,(?"``@$[__]X[__^].P```&```$)@`0!>
MC3X&2%4!`%V=```(+/#_@D"@__]+````8```0F!X0PI];/__2P```&```$)@
M<``!^W@`(?L```!@,(!"ZP``&NL``#CI```I+-0`@D%XPPE_``"@.P```&``
M`$)@"0!)Z7CKI'\!`+T[```J+/#_@D`#`(0XM`>$?"0?A'@```!@N($B@0``
M"2QD`()``0`@.0```&!X(X-\N($BD2'S_TL8`$'H>1MY?)``@D&T![M_>,,$
M?R0?>WMXVV5_8?3_2Q@`0>@``#K[`0`].0``0#ED`*&3M`<I?20?*7DJ25E]
M<``!ZW@`(>L(_O]+>,,#?PWN_TL8`$'H```C+```>OAX&WE\-`""0;0'NW\D
M'WM[N/__2P``0#D0_O]+$`"`.```H#M8__]+<``!^W@`(?MM\?]+&`!!Z'``
M`>MX`"'K</[_2P`````````!@`@``````&````!@``!"8`(`3#R@4T(XI@((
M?/C_X?L0``'XT?\A^````&#^_\(\8(#BZP```&`X@*+H_O^"/!1J_W^@*L8X
M:.F$.```?^BA\O]+&`!!Z```?^C^_^(\_O^B/-CLYSC^_X(\````.=#(I3AX
M.^9\B.F$.%7N_TL8`$'H,``A.!```>CX_^'KI@,(?"``@$X``````````8`!
M``````!@````8```0F`"`$P\`%-".*8""'P0``'XX?\A^````&#^_\(\8(`B
MZ0```&`X@*+H_O^"/!1J*7V@*L8X:.F$.```:>@%\O]+&`!!Z"``(3@0``'H
MI@,(?"``@$X``````````8`````"`$P\H%)".*8""'SH_Z'[\/_!^_C_X?L0
M``'X>`L@?`'P(?@!\`'X8?\!^```P#OPCRWI>"`A^0``(#E%[?]+&`!!Z&@`
MX3O^_\(\_O^"/'@;97R@Z<8XJ.F$.'C[XW]P$*$[/>__2Q@`0>@`$*`X>/OC
M?WCKI'^I[_]+&`!!Z````RP\`(!!>!M_?`$`8SBT!V-\S?#_2Q@`0>AY&WY\
M(`""0;0'_W]XZZ1_>/OE?Y'K_TL8`$'H```@.:[Y/GUX($'I\(\MZ7E*2GT`
M`"`Y)`""0*`@(3AX\\-_$``!Z.C_H>OP_\'K^/_AZZ8#"'P@`(!.3>__2Q@`
M0>@``````````8`#``````!@``!"8`(`3#R044(X\/[_2P``````````````
M`````&```$)@`@!,/'!10CBF`@A\V/]A^^#_@?LF`&!]^/_A^Q```?AX"R!\
M"`!AD0'P(?B1_@'X`!$`.'@;?'S^_V(\S@'A?W@CGWS`Z6,X9`"!./"/+>GX
M$"'Y```@.8'V_TLO`(`X>!M[?'CC@W_)Z_]+&`!!Z```(RQ<`()!_O]B/'CC
MA'_0Z6,X5?K_2WCC@W_X$$'I\(\MZ7E*2GT``"`YI`."0)#_`#AP$2$XS@#A
M?Q```>@(`&&!V/]AZ^#_@>OX_^'KI@,(?"`!<7T@@7!](`"`3GC[XW]`$4'[
M_O]"/S7M_TL8`$'HX.E:.P``.RYXTT1_`>__2Q@`0>AY&W]\/`."06`1P?L@
M!6E[&!&A^HP#X!,``*`Z(!'!^B@1X?K^_\(^_O_B/L`/J2TP$0'[.!$A^P"`
MM6)8$:'[Z.G6.O#I]SKX`"$[:``!.P``H#L``$)@```_B0``"2RH`8)!9`"2
M0>`!C$`@!>E[P`\I+-0!@$"9W@!\F?X@?```0#D&""`0!O@`$%<-`/`&_"`0
MU`&800P%`!!L`@`09P`(?/__*#EX0"E]]`,I?11**GVN2%M]KDA_?%!08WP`
M``,L``&"07C[XW^-Z_]+&`!!Z`$`'SG__T,Y>!M^?!127WT4&C]]0%`_?'@`
M@$!02$A]`0!'<1P`@D'__^F,+P`'+%``@D!`2"A\``"IFT0`@D%"^$IYI@-)
M?2@``$@```!@``!"8/__J9O__RHY__\*B2\`""P<`()`__^JFQ0`0$+__PF)
M__]).2\`""S8_X)!>/OC?P'K_TL8`$'H>!M^?'CC@W_QZO]+&`!!Z!3R8WP!
M`&,X_P\C*&``@4%X^^5_>..'?WBSQGYXN^1^>,LC?^7K_TL8`$'H>,,$?WC+
M(W\UZO]+&`!!Z````RP4`()`@``A@28$*54`J`E\*`&"07C31'\``&`X+>W_
M2Q@`0>AY&W]\@/Z"0!@1H>H@$<'J*!'AZC`1`>LX$2'K0!%!ZU@1H>M@$<'K
MA/W_2P```&```$)@%`"200``.XG2_RDY```)+"``@D'^_^(_`0#`.[CI_SL\
M__]+````8````&```$)@`0`[B0``"2R$_X)!V/__2WC[Y']XVV-_:>[_2Q@`
M0>AH_O]+````8````&```$)@$`!`.9E6.WR95K]]!O@!$`9H(1!7#0#P!OP@
M$!3^F$`@`$`YF58[?)E6OWT&^`$0!F@A$%<-`/`&_"`0]/V80#``0#F95CM\
MF5:_?0;X`1`&:"$05PT`\`;\(!#4_9A`0`"?.$``>SCI[?]+&`!!Z.C]_TL`
M``!@````8```0F`!`(`X>,LC?\GG_TL8`$'H```#+,C^@D#^_V(\>,LD?]#I
M8SC5]O]+>,LC?P7J_TL8`$'H&!&AZB`1P>HH$>'J,!$!ZS@1(>M`$4'K6!&A
MZV`1P>M8_/]+0!%!ZSS\_TL8$:'Z(!'!^B@1X?HP$0'[.!$A^T`10?M8$:'[
M8!'!^['J_TL8`$'H``````````.`"P``````8````&```$)@`@!,//!,0CBF
M`@A\^/_A^Q```?C1_R'X+P"`.'@;?WRQ[/]+&`!!Z```(RP(`()!`0#C.WC[
MXW]9Z?]+&`!!Z#``(3@0``'H^/_AZZ8#"'P@`(!.``````````&``0```@!,
M/)!,0CBF`@A\Z/^A^_#_P?L0``'X>`L@?`'P(?BQ_P'X>1M^?/"/+>DH$"'Y
M```@.1P!@D$``#Z)```)+!`!@D%($.'[*>C_2Q@`0>@``*`[`0"C.'@;?WP`
M$"4H0`&!03`0@?LH`($[>//$?WCC@W^]Y?]+&`!!Z/__/SD42CQ]0$@\?%0`
M@$`4^OQ_*0#A.%#X1WT````Y`0!&<=``@D!"^$EYI@,I?2```$C__Q^9___J
M.___ZH@O``<L'`""0/__"ID4`$!"____B/__7SDO``<LV/^"02\`@#AXXX-_
MC>O_2Q@`0>@``",LP`""04#@(WR8`(%!>..#?S'H_TL8`$'H,!"!ZT@0X>MX
M&WU\*!!!Z?"/+>EY2DI]```@.:P`@D!0$"$X>.NC?Q```>CH_Z'K\/_!ZZ8#
M"'P@`(!.````8````&```$)@_O]B/+CI8SC9Y_]+&`!!Z'@;?7RP__]+````
M8```0F#__]^,+P`&+&3_@D!`.#]\``"_FR#_@D!4__]+``!"8```(#D``".9
M9/__2P``0F!($.'K</__2P```&```$)@_O]B/+CI8SAYY_]+&`!!Z#`0@>M(
M$.'K>!M]?$C__TLP$('[2!#A^UGH_TL8`$'H``````````&`!`````!"8`(`
M3#R@2D(XI@((?-#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?AA_R'X\(\M
MZ6@`(?D``"`Y_O_"/V0`X3OXZ=X[>/OD?WCSPW^][_]+```C+%``@D%F`$'I
M````8#"`(ND```GI)!]*>112*'T(`.GH```G+"I1Z'S(_X)!$`!)Z0``*BP)
M`$GY]/^"0'C[Y']X\\-_<>__2P``(RRX_X)`_O_"/PCJWCMX^^1_>//#?U7O
M_TL``",L6`""068`0>D```!@,(`BZ0``">DD'TIY%%(H?0@`Z>@``"<L*E'H
M?,C_@D$```!@``!"8!``2>D``"HL"0!)^?3_@D!X^^1_>//#?P'O_TL``",L
ML/^"0/[_PC\0ZMX[>/OD?WCSPW_E[O]+```C+%@`@D%F`$'I````8#"`(ND`
M``GI)!]*>112*'T(`.GH```G+"I1Z'S(_X)!````8```0F`0`$GI```J+`D`
M2?GT_X)`>/OD?WCSPW^1[O]+```C++#_@D#^_\(_(.K>.WC[Y']X\\-_=>[_
M2P``(RQ8`()!9@!!Z0```&`P@"+I```)Z20?2GD44BA]"`#IZ```)RPJ4>A\
MR/^"00```&```$)@$`!)Z0``*BP)`$GY]/^"0'C[Y']X\\-_(>[_2P``(RRP
M_X)`_O_"/RCJWCMX^^1_>//#?P7N_TL``",L6`""068`0>D```!@,(`BZ0``
M">DD'TIY%%(H?0@`Z>@``"<L*E'H?,C_@D$```!@``!"8!``2>D``"HL"0!)
M^?3_@D!X^^1_>//#?['M_TL``",LL/^"0/[_HC\XZKT[>/OD?WCKHW^5[?]+
M```C+%@`@D%F`$'I````8#"`(ND```GI)!]*>112*'T(`.GH```G+"I1Z'S(
M_X)!````8```0F`0`$GI```J+`D`2?GT_X)`>/OD?WCKHW]![?]+```C++#_
M@D#^_Z(_P.F].WC[Y']XZZ-_)>W_2P``(RQ8`()!9@!!Z0```&`P@"+I```)
MZ20?2GD44BA]"`#IZ```)RPJ4>A\R/^"00```&```$)@$`!)Z0``*BP)`$GY
M]/^"0'C[Y']XZZ-_T>S_2P``(RRP_X)`_O^"/TCJG#MX^^1_>..#?[7L_TL`
M`",L6`""068`0>D```!@,(`BZ0``">DD'TIY%%(H?0@`Z>@``"<L*E'H?,C_
M@D$```!@``!"8!``2>D``"HL"0!)^?3_@D!X^^1_>..#?V'L_TL``",LL/^"
M0/[_8C]8ZGL[>/OD?WC;8W]%[/]+```C+%@`@D%F`$'I````8#"`(ND```GI
M)!]*>112*'T(`.GH```G+"I1Z'S(_X)!````8```0F`0`$GI```J+`D`2?GT
M_X)`>/OD?WC;8W_QZ_]+```C++#_@D#^_T(_:.I:.WC[Y']XTT-_U>O_2P``
M(RQ8`()!9@!!Z0```&`P@"+I```)Z20?2GD44BA]"`#IZ```)RPJ4>A\R/^"
M00```&```$)@$`!)Z0``*BP)`$GY]/^"0'C[Y']XTT-_@>O_2P``(RRP_X)`
M_O]"/]#I6CMX^^1_>--#?V7K_TL``",L6`""068`0>D```!@,(`BZ0``">DD
M'TIY%%(H?0@`Z>@``"<L*E'H?,C_@D$```!@``!"8!``2>D``"HL"0!)^?3_
M@D!X^^1_>--#?Q'K_TL``",LL/^"0/[_8CQX^^1_>.IC./GJ_TMY&V1\#`""
M07C;8W_I[O]+_O]B/'C[Y'^0ZF,XV>K_2WD;9'P0`()!_O]B/*CJ8SC%[O]+
M_O]B/'C[Y'^XZF,XM>K_2WD;9'Q8`()!>.NC?Z7N_TO^_X(\>//#?^#JA#B5
M[O]+:`!!Z?"/+>EY2DI]```@.5``@D"@`"$X$``!Z-#_0>O8_V'KX/^!Z^C_
MH>OP_\'K^/_AZZ8#"'P@`(!._O]B/'C[Y'_(ZF,X2>K_2WD;9'R@_X)!>..#
M?SGN_TN4__]+:>+_2Q@`0>@``````````8`&`````$)@`@!,/+!$0CBF`@A\
M$``!^)'_(?C^_V(\9`"!.$CJ8SCPCRWI:``A^0``(#GMZ?]+```C+$P`@D$`
M`".)``!@.```"2P4`()!,``I:30`*7U^V2E5`0`C:6@`0>GPCRWI>4I*?0``
M(#FT!V-\'`""0'``(3@0``'HI@,(?"``@$X``&`XU/__2\GA_TL8`$'H````
M``````&```````!"8`(`3#P01$(XI@((?!```?CA_R'X````8$"`8NE(`('X
M>!MD?%``H?A(`*$X6`#!^&``X?AH``'Y``!KZ'``(?EX`$'Y[>#_2Q@`0>C_
M`&`X@>/_2Q@`0>@``````````8````````!@````8```0F`"`$P\H$-".*8"
M"'S__X$]V/]A^^#_@?OH_Z'[\/_!^_C_X?L0``'X>`L@?`'P`?@`8"%\^/^"
M0%'_`?@!`$`]$``A.6@`2F$42DI]`@"@.```@#CPCRWI```J^0``(#EX&WU\
M/>/_2Q@`0>C__\,[=(;>?Y0!WG_E@]Y[0`&`00$`(#V``&$["``I8?#_^SO_
M_X`_:``A^0```&```$)@``"@.'CSQ']XZZ-_]>+_2Q@`0>C__R,L&`&"06@`
MH>AX^^1_>.NC?YG<_TL8`$'H__\#+/``@D&T!V-\!P`C*-``@4#X_V,X%!H_
M?4#X*7S``(!!*A@??0```&`(@4+I````8.`')GD(@>(X`$`J?$P`@D'__RDY
M0/@I?)0`@$$``"8L&`""02@``$@``$)@__\I.4#X*7QX`(!!``!'Z0``">D`
M0"I\%`""0?__*3D```GI`$`J?-C_@D#P_WLX4$AC?!3R8WP!`"`]$`!!.6@`
M*6$44BE]``!)Z?"/+>EY2DI]```@.50`@D```"'H$``!Z-C_8>O@_X'KZ/^A
MZ_#_P>OX_^'KI@,(?"``@$[__]X_`.`^?.C^@D#__V`XJ/__2_[_8CSXZF,X
MS?W_2_[_8CSHZF,XP?W_2V7?_TL8`$'H``````````&`!0```@!,/+!!0CBF
M`@A\$``!^.'_(?B]W_]+&`!!Z+7=_TL8`$'H```C+`@`@D$``&/H(``A.!``
M`>BF`PA\(`"`3@`````````!@```````0F`"`$P\8$%".*8""'SH_Z'[\/_!
M^_C_X?L0``'X<?\A^/[_HC]X&WY\".N].V0`@3AXZZ-_\(\MZ6@`(?D``"`Y
MB>;_2WD;?WP0`()!```_B0``"2Q,`()`>//$?WCKHW]IZO]+:`!!Z?"/+>EY
M2DI]```@.90`@D"0`"$X$``!Z.C_H>OP_\'K^/_AZZ8#"'P@`(!.````8```
M`&```$)@>//#?W``@?N9W/]+&`!!Z'@;?'QX^^-_B=S_2Q@`0>@4&GQ\`@!C
M.%G?_TL8`$'H_O_"//[_@CQX^^=_>//%?^#IQCCPZ80X>!M\?'7=_TL8`$'H
M>..$?WCKHW_-Z?]+<`"!ZV#__TMP`('[]=W_2Q@`0>@``````````8`$```"
M`$P\0$!".*8""'S8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@1_B'X$`"`.```
M`&`H`,`X"($B.3@`X#@```!@<(&BZ````&`H@6+I2```.5@`0#F8)BE]F#9)
M??[_8C_0_L`XF#YI?9A&B7T`_^`X$/\`.9A6"7QL`*$[(/]`.>C^(#G`Z7L[
M>!M\?/"/;>B8`6'X``!@.)@`H?B``&'YH`&A.'CKI'^8-R5]>-MC?Y@_17V8
M1V5]F%>%?9A/!7SIY/]+>1M_?!``@D$``#^)```)+$P#@D"P`0'[N`$A^\`!
M0?M]W?]+&`!!Z'7;_TL8`$'H```C+)@"@D$``,/K```^+(P"@D%X\\-_%=O_
M2Q@`0>BD#V-X`0!C..7=_TL8`$'H``"^B'@;?WQX&WI\```%+#``@D'^_R(_
M(.LY.R``I7AX^^-_>,LD?P(`_SOQV_]+&`!!Z`$`OHP```4LX/^"0/[_8CR@
M`,$[J.IC.!P``$@```!@````8```0F`)`'[H```C+$@`@D%XZZ1_&>3_2WD;
M?WSH_X)!```_B0``"2S<_X)!0>7_2P```RS0_X)!>/OC?RG;_TL8`$'H>1M_
M?%@`@D````!@``!"8&@`P3L```!@````8```0F`)`/[K```_+#0`@D$``#^)
M```)+(P!@D%X^^-_[>3_2P```RS<_X)!>/OC?]7:_TL8`$'H>1M_?,C_@D%X
M^^-__O\"/_W9_TL8`$'HZ.D8.W@;?GQXTT-_Z=G_2Q@`0>@4&MY_!`3>.[0'
MWG]X\\-_L=S_2Q@`0>C^_^(\_O^"/'C32']X^^5_>,,&?RCKYS@PZX0X>!MY
M?,G:_TL8`$'HP`&`.'C+(W\YW?]+&`!!Z/__`RP8`()`*=K_2Q@`0>@``..`
M$0`'+$0!@D#0`($X>,LC?VW:_TL8`$'H```#+'@;?WQ\`()!````8$"`(ND`
M`+SH_O^"/'C+)G^`ZX0X``!IZ-W6_TL8`$'HL`$!Z[@!(>O``4'K``#`.P``
M0F"8`4'I\(\MZ7E*2GT``"`YT`6"0/`!(3AX\\-_$``!Z-C_8>O@_X'KZ/^A
MZ_#_P>OX_^'KI@,(?"``@$X``$)@Z``A@28$*54`0`DH?/^"0.P`08,-V_]+
M&`!!Z``8&GQH_X)`Z``A@:@!X?K^!2E5P`$)*.@`@D&H`>'J3/__2P``X#N8
M_O]+````8```0F"``.$[````8````&```$)@"0!_Z```(RR0`()!>.ND?_GA
M_TMY&VE\Z/^"00``*8D```DLW/^"01G9_TL8`$'H>1M^?,S_@D%)V/]+&`!!
MZ*0/8W@!`&,X-/W_2P```&!`@"+I``"\Z/[_@CRT!^=\>,LF?T#KA#@``&GH
MM=7_2Q@`0>C8_O]+````8```0F#)^O]+>/OC?[G8_TL8`$'H>!M^?,S^_TL-
M`&`X_O_"/\':_TL8`$'H&.O>.U,`H#AX&W]\>!MZ?.#\_TMX\\-_H=K_2Q@`
M0>AXZZ1_>!M^?/[_8CS8ZV,X,>'_2WD;9'S@`8)!``!\Z%'J_TMY&W=\T`&"
M07B[XWZ)U_]+&`!!Z`,``RQX&WI\J`"!0+0'8WS^_X(\_/]C..#KA#@4&G=\
M(`5I>,`/*2SP`H!`(`6)>,`/*2SD`H!`F1X`?)DFH'V,`R`0``!`.09HH!$&
M"``05VT`\`8,H!%8`IA!#`4`$&P"`!!G``A\__\H.7A`*7WT`RE]%$HJ?:Y(
M0WVN2&1\4%!C?````RPH`()`!``:+)0"@D'[_SHYM`<I?:Y(-WTO``DL@`*"
M00```&```$)@_O^"/WCKI'](ZIP[>..#?TG@_TL``",L"`&"00``(XD```DL
M_`""03``"2ST`()!_O^"/'CC@W_@ZH0X_O^B/QGD_TO8[+T[_O^"/R#LG#N!
MU?]+&`!!Z/[_@CQXPP9_>.NH?WC+)7]X&V=\$.R$.'CSPW]]U_]+&`!!Z$@`
M`$CQUO]+&`!!Z```(X$1``DL3`""0#W5_TL8`$'H`0#_.WCKJ7^T!^A_>,,&
M?W@;9WQXRR5_>..$?WCSPW\UU_]+&`!!Z,`!@#AX\\-_I=G_2Q@`0>C__P,L
MJ/^"07C+(W]QU/]+&`!!Z'CSQ']XVV-_:>/_2WCSPW^A^/]+J`'AZK`!`>NX
M`2'KP`%!ZZ3\_TL``/SJ,/[_2P```&```$)@>+OC?@``@#C)U?]+&`!!Z```
M`RQX&WU\^/Z"01WV_TMY&WI\[/Z`00``H#CV_YHX>.NC?V`!X3J9V?]+&`!!
MZ`8`H#AXZZ-_>+OD?D73_TL8`$'H!@`C+#`"@D!@`4&!04-);0!#"2RH_H)`
M!``WH4A%"2R<_H)`SO^:.```H#AXZZ-_:`'A.TG9_TL8`$'H*`"@.'CKHW]X
M^^1_``"`._'2_TL8`$'H*``C+-P!@D#^_P(]_O^"/)`!@9MX^^=_>,,&?]CL
M"#EXRR5_`.R$.'CSPW_]U?]+&`!!Z.#^_TL0`$`YF5:C?9E6A'T&"`T0!F"M
M$5=M`/`&#*`1D/V80"``0#F95J-]F5:$?08(#1`&8*T15VT`\`8,H!%P_9A`
M,`!`.9E6HWV95H1]!@@-$`9@K1%7;0#P!@P@$%#]F$!``(0X0`!C.,G8_TL8
M`$'H9/W_2P@`G.L``#PLA/V"07CC@W]-U/]+&`!!Z`,`(RAP_8%`_/]C./[_
M@CP4&GQ\Z.N$."`%:7C`#RDLU`"`0"`%B7C`#RDLR`"`0)D>`'R9)J!]C`,@
M$```(#D&:*`1!@@`$%=M`/`&#*`1/`"800P%`!!L`@`09P`(?/__2#EX0$I]
M]`-*?112*7VN2$-]KD@D?5!0*7T```DL]/R"0'CCEW_L_/]+$``@.9E.HWV9
M3H1]!@@-$`9@K1%7;0#P!@R@$:S_F$`@`"`YF4ZC?9E.A'T&"`T0!F"M$5=M
M`/`&#*`1C/^80#``(#F93J-]F4Z$?08(#1`&8*T15VT`\`8,(!!L_YA`0`"$
M.$``8SBQU_]+&`!!Z'@;:7Q\__]+J`'A^K`!`?NX`2'[P`%!^_'4_TL8`$'H
M_O]B//#K8S@Y\_]+``````````&`"0```@!,/#`W0CBF`@A\X/^!^^C_H?OP
M_\'[^/_A^Q```?AA_R'X````8/"/+>EH`"'Y```@.6"`XNL4:C]]9`"A._[_
M8CP``,GK*.IC.'CKI'^P`#Z)L0`^F4'<_TL``",L$`""00``(XDQ``DLY`&"
M02GL_TL4:C]]``#)Z_[_@CQX\\-_`P#`.`$`H#@X[(0XX='_2Q@`0>AY&WY\
M.`""01``/ND4:I]__O^B/$#LI3@``'SH``")Z%G0_TL8`$'H$``^Z0``B>@,
M`"2!0``I==`!@D`4:I]__O^"/`,`P#@!`*`X``!\Z$CLA#B%T?]+&`!!Z'D;
M?GPP`()!_O]B/'CKI'_0Z6,XD=O_2WD;97Q0`8)!$``^Z0``?.@``(GH\<__
M2Q@`0>@4:O]__O^"/`$`H#A0[(0X``#?ZWCSPW]QT?]+&`!!Z/[_HCQH[*4X
M>!MD?'CSPW^YS_]+&`!!Z```/^D``$`Y_O]B/'CKI'_`Z6,XL0!)F2';_TL`
M``!@```C+,B!8OB8`()!P`&`."'5_TL8`$'H`0`C.0$`"2A``(%`$0`#+#@`
M@D%X`&'[````8,"!(ND```!@R(&BZ'@;9GS^_V(\F.QC.```B>@!T?]+&`!!
MZ````&```$)@:`!!Z?"/+>EY2DI]```@.=P`@D"@`"$X$``!Z.#_@>OH_Z'K
M\/_!Z_C_X>NF`PA\(`"`3@```&````!@``!"8````&#`@6+HT?3_2P```&``
M`",LR(%B^%3_@D#^_V(\>`!A^W#L8SB)T/]+&`!!Z`$`(XD```DL)/Z"013^
M_TMX`&'[->+_2Q``/NEY&WM\``!\Z```B>@X`()!>-ME?Y'._TL8`$'H>-MC
M?P7/_TL8`$'H>`!AZY#^_TL``$)@``!\Z(W/_TL8`$'H*/[_2P```&#`@2+I
M``"IZ%7._TL8`$'H>`!AZV#^_TMX`&'[`=+_2Q@`0>@``````````8`%````
M``!@````8```0F`"`$P\0#1".*8""'SX_^'[$``!^('_(?AX&W]\_O]B/&0`
M@3A(ZF,X\(\MZ6@`(?D``"`Y==G_2P``(RPL`()!```CB0``"2P@`()!,``)
M+!@`@D$``#\L$`""00``/XD```DL+`""0&@`0>GPCRWI>4I*?0``(#G(`()`
M@``A.!```>CX_^'KI@,(?"``@$YX^^-_<`#!^R'G_TLO`(`X>!M^?'W3_TL8
M`$'H```C+`@`@D$!`,,[>//#?R70_TL8`$'H_O\"/0``(#DHZP@Y+!Q`?2Q$
M`'T"`$IY`@`(>?A+27WX0T=].3LI?20`@D%T`"E]"``I.3!.2GDP3@AY`$`J
M?`P`@D%P`,'K7/__2V@`0>GPCRWI>4I*?0``(#DD`()`<`#!ZX``(3AX^^-_
M$``!Z/C_X>NF`PA\?-K_2W``P?N=T/]+&`!!Z``````````!@`(``````&``
M``!@`@!,/.`R0CC`_P'[R/\A^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q']
M(?@(`$`YI@-)??"/+>FH`B'Y```@.2``(3DX`,,X>$LG?0``0F````;I+#2@
M?!``YS@(`,8X(,(*>2!&!'DN!$I5(@`(>7@C2GTHP`1Y>"-*?1Y""%5X0TI]
M(`"H>/C_1_GP_P?YP/\`0K`"83FP_>`XH/W`.,#]@#B8/HM]_O_B/-#]H#C@
M*N<XF#8K??[_PCR8)DM]T"K&.)#]0#F8+FM]F#Z`?"``X#B`_0`YI@/I?)DV
MH'V85@M]_O]"/<`J2CF81NM\X/T`.9E6@'V81@M\@`!`.6@``#D```!@````
M8```0F"91BE\F$Z@?-`\S/"01.CPD$P)\9!D+/&05(KQD%Q+\9`$8/'5+"'P
MU30A\,1F`1#$;2$0E@P`\!`D`/"85PE\$``I.;S_`$(```/H(``!Z1``P^@8
M`*/H&X]`/6+*(#T(`(/H(`!CZ2@`@>DP`,'KW+Q*8=;!*6$@`$IY(``I><(N
M''BD+A]X@EKH/'CC_W^9>><X>"K<?(+PG7@46N=\9/"(>"``_WLX()Q_>.L(
M?7@JG'\4.O]_(``=>13B_W]XZL=\XB[[>\@N_'N"6HP]>-N<?X+P&G@X`.=\
M9/`;>)EYC#EXTWM_%"J,?7@RYWP@`/][%&+G?#@`@>EXV@A]@EK>/Q3BYWPX
M^`A]F7G>.^(N_'@4,MY_R"[Z>'CJ"'UXXUI_%/((?63P_'M``,'K@O#_>X):
MC#UX^YQ_%-((?9EYC#D@`.=X>.)_?Q3JC'W(+AIYXBX=>2``>WMXZUI_.#C_
M?V3P_7B"\.=X>-K_?W@[O7\@``AY>.J'?Q1B_W](`('I@EK>/Q32_W\X0.=\
M(`":>YEYWCMXTN=\%-K>?V3P''F"\`AYR"[[>WA#G'\4\N=\XB[^>WCBJ']X
M\WM_(`#_>U``P>N"6HP]%-KG?#CX"'UD\/M[F7F,.8+P_WMX^WM_(`"X>U@`
MX>L4THQ]XB[]>,@N^GAXP@A]>.M:?X):WC\@`/UX>-J'?R``F7L48@A]L`"!
MZ3CHYWR9>=X[%-((?13"WG]XRN=\R"X:>13RYWSB+AYY>/-:?V3PO'N"\+Y[
M@EK_/WCSG'\@`!UY8`#!ZWCB:'\@`'A[..@(?9EY_SL4TN=\%,K_?WC""'W(
M+OIX%/H(?>(N_WAX^UI_9/"[>X+POWN"6MX_>/M[?R``_7AH`.'K>-J'?R``
MF7LXZ.=\F7G>.Q32"'T4PMY_>,KG?,@N&GD4\N=\XBX>>7CS6G]D\+Q[@O"^
M>X):_S]X\YQ_(``=>7``P>MXXFA_(`!X>SCH"'V9>?\[%-+G?!3*_W]XP@A]
MR"[Z>!3Z"'WB+O]X>/M:?V3PNWN"\+][@EK>/WC[>W\@`/UX>`#AZWC:AW\@
M`)E[..CG?)EYWCL4T@A]%,+>?WC*YWS(+AIY%/+G?.(N'GEX\UI_9/"\>X+P
MOGN"6O\_>/.<?R``'7F``,'K>.)H?R``>'LXZ`A]F7G_.Q32YWP4RO]_>,((
M?<@N^G@4^@A]XB[_>'C[6G]D\+M[@O"_>X):WC]X^WM_(`#]>(@`X>MXVH=_
M(`"9>SCHYWR9>=X[%-((?13"WG]XRN=\R"X:>13RYWSB+AYY>/-:?V3PO'N"
M\+Y[@EK_/WCSG'\@`!UYD`#!ZWCB:'\@`'A[..@(?9EY_SL4TN=\%,K_?WC"
M"'W(+OIX%/H(?>(N_WAX^UI_9/"[>X+POWN"6MX_>/M[?R``_7B8`.'K>-J'
M?R``F7LXZ.=\F7G>.Q32"'T4PMY_>,KG?,@N&GD4\N=\XBX>>7CS6G]D\+Q[
M@O"^>X):_S]X\YQ_(``=>:``P>MXXFA_(`!X>SCH"'V9>?\[%-+G?!3*_W]X
MP@A]R"[Z>!3Z"'WB+O]X>/M:?V3PNWN"\+][@EK>/WC[>W\@`/UXJ`#AZWC:
MAW\@`)E[..CG?)EYWCL4T@A]%,+>?WC*YWS(+AIY%/+G?.(N'GEX\UI_9/"\
M>X+POGN"6O\_>/.<?R``'7EXXFA_F7G_.R``>WLXZ`A]%-+G?!3*_W]XV@A]
MR"[Z>!3Z"'WB+O]X>/M:?V3POGN"\+][@EJ,/7C[W7\4T@A]N`#!ZR``YWAX
MZI]_F7F,.2``FGL4VHQ]XBX<>3@X_W\H*!MY>.-[?WC2_W]D\/QX@O#G>'@[
MG'\48O]_P`#AZ!3:GWT@``AY>.*_?X):WC\@`+M[.$#_?YEYWCMXVO]_%-+>
M?^(NG7D4\O]_*"B>>7CKWG]D\!UY@O`(>13R_W]X0[U_VF[G/,@``>EXZIY_
MB/":>7ABWG^AZ^<XHO",>13:YWQX8UI_XB[[>R@H^7L@`-Y[>-LY?Q0ZWG\@
M`)M[VF[H/-```>EXTKQ_H>OG.'CZG'\4RMY_%-KG?"``G'OB+ME[%.+G?"@H
MVWN(\/Q[HO#_>WC+>W]X^YQ_VFX(/=@`X>L4VH=](`"]>WCB1W^AZP@YXBZ;
M>7CRYWP4Z@A]*"B=>7C;O7\@`.=XB/#;>Z+PWGMX\WM_%#H(?>``X>@4ZLA_
MVF[_/WC:B'\@`%I[>&((?:'K_SOB+ME[%-+_?R``"'DH*-I[B/"=>:+PC'EX
M8[U_%$+_?^@``>EXRUI_VF[G/!32GWT@`)Q[>.I_?Z'KYSAX\O]_%.+G?"@H
MFGGB+IQY>.-:?R``_WN(\-Q[HO#>>WCSG'\4^N=\\`#AZQ32QW_:;@@]>.*G
M?R``>WMX8N=\H>L(.>(NV7L4V@A](`#G>"@HVGN(\)MYHO",>7AC>W\4.@A]
M^`#AZ'C+6G_:;O\_%-*(?2``O7MXVHA_H>O_.WCR"'T4ZO]_*"B:>>(NG7EX
MZUI_(``(>8CPW7NB\-Y[>/.]?Q1"_W\``0'I%-+??]INYSQXZG]_(`"<>WAB
M_W^AZ^<XXB[9>Q3BYWP@`/][*"C:>XCPG'FB\(QY>&.<?Q3ZYWP(`>'K>,M:
M?]IN"#T4TH=](`![>WCBIW^AZP@Y>/+G?!3:"'TH*)IYXBZ;>7C;6G\@`.=X
MB/#;>Z+PWGMX\WM_%#H(?1`!X>@4TLA_VF[_/WC:B'\@`+U[>&((?:'K_SOB
M+ME[%.K_?R``"'DH*-I[B/"=>:+PC'EX8[U_%$+_?Q@!`>EXRUI_VF[G/!32
MGWT@`)Q[>.I_?Z'KYSAX\O]_%.+G?"@HFGGB+IQY>.-:?R``_WN(\-Q[HO#>
M>WCSG'\4^N=\(`'AZQ32QW_:;@@]>.*G?R``>WMX8N=\H>L(.>(NV7L4V@A]
M(`#G>"@HVGN(\)MYHO",>7AC>W\4.@A]*`'AZ'C+6G_:;O\_%-*(?2``O7MX
MVHA_H>O_.WCR"'T4ZO]_*"B:>>(NG7EXZUI_(``(>8CPW7NB\-Y[>/.]?Q1"
M_W\P`0'I%-+??]INYSQXZG]_(`"<>WAB_W^AZ^<XXB[9>Q3BYWP@`/][*"C:
M>XCPG'FB\(QY>&.<?Q3ZYWPX`>'K>,M:?]IN"#T4TH=](`![>WCBIW^AZP@Y
M>/+G?!3:"'TH*)IYXBZ;>7C;6G\@`.=XB/#;>Z+PWGMX\WM_%#H(?4`!X>C:
M;O\_%-+(?R``O7MXVHA_H>O_.WAB"'T4ZO]_B/"=>:+PC'GB+MI[>&.]?R@H
MV7M0`8'I>-,Y?R``"'D@`)I[VF[G/'CJ?'\40O]_2`$!Z7CRG'^AZ^<X%,K_
M?Q32YWP@`)Q[XB[Y>Q3BYWPH*/I[B/#<>Z+PWGMX\YQ_>,M:?Q32QW_:;@@]
M>.*G?R``>WMX^N=\H>L(.>(NV7L4V@A](`#G>"@HVGN(\/M[HO#_>WC[>W\4
M.@A]6`'AZ'C+6G_:;HP]%-+H?WC:B'\@`+U[>/((?:'KC#D@``AY%.J,?<@N
M_7L40HQ]XB[H>WA#J'^(\-U[HO#>>Q1"C'UX\[U_VF[G/&`!P>MXZFA_(`"<
M>WCZ"'VAZ^<X%.+G?"``"'D40N=\B/#H>Z+P_WOB+IQY>/L(?<@NFGEXXUI_
M>$._?R``G'D@`'M[(``,>13RRG\4VMY_..#_?SA@NW\4TN=\:`%!ZWC;_W_(
M+OEX%/+_?^(N_GAX\SE_9/">>X+PG'L@`/MX>./>?Q3*_W]P`8'K>/,(?3A@
MQW\4TDI_.-@(?2``O7MX.PA]%.JZ?^(NYWO(+OI[%.H(?7@[6G]D\&=[@O![
M>R``_7MXV^=\%-((?7@[WW\@`/IX.-#;?Q3BBG\XZ/]_%&*<?WC;_W_(+AMY
M%.+_?^(N''EXXWQ_9/"[>X+PO7L@``AY>.M[?R``WGMXV^Q\>`'AZ!3B_W\X
M0(Q](`#]>Q0ZZGP4\N=\.-!^?WCSC'W(+OY[%#J,?>(NYWMX.]Y_9/`'>8+P
M"'EX0^=\%/(,?8`!P>L@`/QX>#M_?SCH_W_(+AEY%/+*?Q32WG\XX'I_>-/_
M?Q3R_W_B+AYY>/,Y?V3POGN"\+U[(``(>7CKVG\@`'Y[>-/L?(@!X>@4RO]_
M.$",?2``_7L4.NI\%/+G?#C@7G]X\XQ]R"[^>Q0ZC'WB+N=[>#O>?V3P!WF"
M\`AY>$/G?!3R#'V0`<'K(`#[>'@[7W\XZ/]_R"X9>13RRG\4XMY_.-A<?WCC
M_W\4\O]_XBX>>7CS.7]D\+Y[@O"]>R``"'EXZ]Q_(`!>>WCC['R8`>'H%,K_
M?SA`C'T@`/U[%#KJ?!3RYWPXV)Y_>/.,?<@N_GL4.HQ]XB[G>W@[WG]D\`=Y
M@O`(>7A#YWP4\@Q]H`'!ZR``^GAX.Y]_..C_?\@N&7D4\LI_%-K>?SC0FW]X
MV_]_%/+_?^(N'GEX\SE_9/"^>X+PO7L@``AY>.O;?R``GGMXV^Q\J`'AZ!3*
M_W\X0(Q](`#\>Q0ZZGP4\N=\.-!^?WCSC'W(+OY[%#J,?>(NYWMX.]Y_9/`'
M>8+P"'EX0^=\%/(,?;`!P>L@`/UX>#M_?SC@_W_(+AEY%/+*?Q32WG\XZ'I_
M>-/_?Q3R_W_B+AYY>/,Y?V3PGGN"\)Q[(``(>7CCVG\@`'Y[>-/L?+@!X>@4
MRO]_.$",?2``^WL4.NI\%/+G?#CH7G]X\XQ]R"[^>Q0ZC'WB+N=[>#O>?V3P
M!WF"\`AY>$/G?!3R#'W``<'K(`#\>'@[7W\XV/]_R"X9>13RRG\4ZMY_..!=
M?WCK_W\4\O]_XBX>>7CS.7]D\'Y[@O![>R``"'EXV]U_(`!>>]`!0>MXZ^Q\
MR`'AZ!3*_W\X0(Q]R"[[>Q322G\4.NI\%.):?Q3RYWPXX+Y_>/.,?2``_GL4
M.HQ]XB[G>W@[>W]D\`=Y@O`(>7A#YWP4V@Q]>#N_?R``^W@XV+Q_./#_?WCC
M_W_(+AEYXBX<>132_W]XXSE_9/#:>X+PW'L@`+Y[V`&AZWCC6G\@``AY>-/L
M?!3*_WS@`>'K%.JJ?SA`C'T4\MU_.-A=?WCKC'W(+OUX%/*,?>(N_GAX\[Y_
M9/`=>8+P"'D@`/QX>$.G?Q3ZZG_H`:'K%/(,?2``_GAX.TQ_%-K_?SC@C'TX
M\%M_>-N,?<@N&7D4^HQ]XBX?>7C[.7]D\)][@O"<>R``"'EXX_M_%.JJ?R``
M7WMXV^=\%/J]?SA`YWPX\']_%,J,??@!(>MX^^=\R"Z?>13JYWSB+IUY>.O_
M?V3P&GF"\`AY(`"=>7A#6G\4^@=]\`'AZ"``7'MXTVQ_..B,?2@H&'D4.NI_
M..!G?Q3R_W]D\+Y[@O"]>W@[C'UXZ]Y_XBX'>0`"H>L@``AY%/J,?7@[&'\@
M`']["`)AZWCS1W\4RDI].$#G?!3Z2GTXX-]_%,*,?7C[YWQD\!IYXBZ?>112
M1WV"\`AY*"B'>7A#6G]X^^=\$`+AZQ0Z2GT4ZJE_>-+'?Q3BO7^B\(AY>&+G
M?(CPG'D@`.=X>$.<?^(N67EXXDA_%.KG?"@H77D4VFE_>,N]?WA2"'T@`-Y[
M%.KG?!@"H>L4\MM_(``(>>(N^7BB\$QY%/((?8CP6WDH*/YX>&-[?R`"@>EX
MR\I_(`!:>Q12"'UXVHI_%/KI?W@Z2GT4TO]_(`!*>8CP_GBB\.=X>#O>?^(N
M&GDH`N'H%%+_?R@H"GEXTTI]>/)Z?Q12_W\@`)Q[%.I)?7A"77\4XDI](`"]
M>^(N^GL4ZDI]B/`<>2@H_7NB\`AY>-.]?WA#G'\4ZDI],`(!Z7CBW7\@`'M[
M%&*)?7CZO7\4VHQ](`"]>Q3JC'V(\/U[HO#_>^(N6WEX^[U_*"A:>3@"X>MX
MVUI_(`#;>WCJGG\4.NE\>%+>?Q32C'T4VN=\(`#>>^(NFGD4\N=\B/!;>2@H
MGGFB\$IY>-/>?WA3>W\4\N=\0`)!Z7C:OG\@`)Q[%$()?7ABWG\4X@A](`#>
M>Q3R"'V(\)YYHO",>>(N_'AX8]Y_*"CZ>$@"@>EXXUI_(`"\>WCR?7\4^NE_
M>#J]?Q32"'T4XO]_(`"]>^(N&GD4ZO]_B/#\>"@H'7FB\.=X>-.]?W@[G'\4
MZO]_4`+AZ'CBW7\@`'M[%%))?7A"O7\4VDI](`"]>Q3J2GV(\!UYHO`(>>(N
M^WMX0[U_*"CZ>U@"`>EXVUI_(`#;>WCJGG\48HE]>/K>?Q322GT4VHQ](`#>
M>^(N6GD4\HQ]B/#[>R@H7GFB\/][>-/>?WC[>W\4\HQ]8`+AZWC:OG\@`)Q[
M%#KI?'A2WG\4XN=\(`#>>Q3RYWR(\%YYHO!*>>(NG'EX4]Y_*"B:>6@"0>EX
MXUI_(`"\>WCR?7\40@E]>&*]?Q32YWP4X@A](`"]>^(N^G@4Z@A]B/"<>2@H
M_7BB\(QY>-.]?WACG'\4Z@A]<`*!Z7CBW7\@`'M[%/KI?W@ZO7\4VO]_(`"]
M>Q3J_W^(\/UXHO#G>.(N&WEX.[U_*"@:>7@"X>AXVUI_(`#;>WCJGG\44DE]
M>$+>?Q3:2GT@`-Y[%-+_?Q3R2GV(\!YYHO`(>>(N^WMX0]Y_*"CZ>X`"`>EX
MVUI_(`";>WCRO'\48HE]>/J<?Q3:C'T@`)Q[%-)*?13BC'V(\/Q[HO#_>^(N
M6WEX^YQ_*"A:>8@"X>MXVUI_(`"[>WCBW7\4.NE\>%*]?Q3:YWP@`+U[%-*,
M?13JYWR(\%UYHO!*>>(NFWEX4[U_*"B:>9`"0>EXVUI_(`#;>WCJGG\40@E]
M>&+>?Q3:"'T@`-Y[%-+G?!3R"'V(\)YYHO",>2``FGMX8]Y_XB[[>'CRO'\H
M*/EX%/KI?W@ZG']XVSE_%-+_?Y@"8>L@`)Q[%,H(?13B_W^(\/QXHO#G>.(N
M&7EX.X=_*"@:>2``O'MXRUI_>#K=?Q32_W\44DE]B/`:>7A"O7^B\`AY%.)*
M?2``O7MX0UQ_R"[H>^(N^GL4ZDI]%-HI?7C3'7UXXNA\%.I*?7CZ"'T@`-Y[
M%`(I?<@N77D4\BE]XBY;>2``'GFB\.![B/#H>Q3R*7UXV[]_>`,(?10R"'T4
M6N=\%")*?10JO'P4^BE](`!*>2``*7D@`.=X(`"F>"``"'D(`$/Y(`#C^```
M(_D8`,/X$``#^:@"0>GPCRWI>4I*?0``(#DL`()`\`(A.,#_`>O(_R'KT/]!
MZ]C_8>O@_X'KZ/^AZ_#_P>OX_^'K(`"`3J8""'P``P'X/;K_2Q@`0>@`````
M`````8`(``````!@``!"8`(`3#R`'$(XI@((?!```?CA_R'X@`!@."F[_TL8
M`$'H16>@/#(0P#P!(Z1@=E3%8```P#C-[R`]NI@`/=+#0#T``(/X&`"C^'@`
MPY")JREA_MP(82@`P_CPX4IA(``G>3``P_@@``AY(`!*>0@`X_@@`"$X$``#
M^2``0_D0``'HI@,(?"``@$X``````````8````````!@````8```0F`"`$P\
MX!M".*8""'RX_^'ZP/\!^^#_@?OH_Z'[\/_!^_C_X?L0``'XD?\A^'@;?'PD
M'ZEX*`!#Z7@`8X!"'ZAX>"NX?#``_.AX(Y=\.`#<.Q12*7T```,L(``I>1!(
M2GT044I]*``\^5`X*GT42@A],``<^=P`@D`_`!@LE`"!0+[1'5<@`,'Z.``A
M^WB[_WY``$'[2`!A^___W3H0`"`[(`!`.S``8#L```!@``!"8)C^0'V8SG]]
M>..#?YC6GWV8WA]\0`#_.YCW0'V8SWY]F->>?9C?'GPQZ/]+__^]-]#_@D`R
M,,E60`#W.C@`(>M``$'K2`!AZX@VUGK`_Q@[%+KV?B``P>I0P"E]M`<X?7B[
MY'YX\\-_>,,%?V6T_TL8`$'H>``<DW``(3@0``'HN/_AZL#_`>O@_X'KZ/^A
MZ_#_P>OX_^'KI@,(?"``@$Y``.,C`"@??%@`@4&T!V-\.`#<.[0'_7\4&GY\
M>.NE?WB[Y'X-M/]+&`!!Z'@`/($42C]]0``)+'@`/)&<_X)`4,#_?WCC@W^T
M!_A_%.KW?FGG_TO4_O]+````8```0F!X*[]\M`=C?#@`W#NT!_U_%!I^?'CK
MI7]XN^1^M;/_2Q@`0>AX`#R!%$H_?4``"2QX`#R11/^"0*C__TL`````````
M`8`*``````!@``!"8`(`3#S@&4(XI@((?-C_8?O@_X'[Z/^A^_#_P?OX_^'[
M$``!^+'_(?B`_T`Y*``$.3@`I#LH`"3I>!M^?'@CGWPL1(!_,``$.;[N*54L
M1&!_`0"I.+0'*7TX``4LM`>C?*Y)77T4&GU\:`&!0$``I2```(`XM`>E?"FV
M_TL8`$'H>/OC?X7F_TN,`P`0$`!`.2``(#D````Y5@*`\6@`'_F8[X!]F%>=
M?9A/G7UP`'^3=`"?DWC[XW]1YO]+```_Z7C[XW\"1BEY```^F0``/^D"A"EY
M`0`^F0``/^D"PBEY`@`^F0``/^D#`#Z9"``_Z0)&*7D$`#Z9"``_Z0*$*7D%
M`#Z9"``_Z0+"*7D&`#Z9"``_Z0<`/ID0`#_I`D8I>0@`/ID0`#_I`H0I>0D`
M/ID0`#_I`L(I>0H`/ID0`#_I"P`^F1@`/^D"1BEY#``^F1@`/^D"A"EY#0`^
MF1@`/^D"PBEY#@`^F1@`/^D/`#Z9(``_Z0)&*7D0`#Z9(``_Z0*$*7D1`#Z9
M(``_Z0+"*7D2`#Z9(``_Z1,`/IFELO]+&`!!Z%``(3@0``'HV/]AZ^#_@>OH
M_Z'K\/_!Z_C_X>NF`PA\(`"`3@```&```$)@.`"E(```@#BT!Z5\Q;3_2Q@`
M0>C(_O]+``````````&`!0``````8`B6`0``````I@((?`4`GT*F`FA]I@,(
M?/#_"^A08(M]%%I@?=3_##@``(OI@O``>*8#B7T(`&OI(`2`3LS__TO(__]+
MQ/__2\#__TN\__]+N/__2[3__TNP__]+K/__2ZC__TND__]+H/__2YS__TN8
M__]+E/__2Y#__TN,__]+B/__2X3__TN`__]+?/__2WC__TMT__]+</__2VS_
M_TMH__]+9/__2V#__TM<__]+6/__2U3__TM0__]+3/__2TC__TM$__]+0/__
M2SS__TLX__]+-/__2S#__TLL__]+*/__2R3__TL@__]+'/__2QC__TL4__]+
M$/__2PS__TL(__]+!/__2P#__TO\_O]+^/[_2_3^_TOP_O]+`@!,/,P60CBF
M`@A\$``!^.'_(?@@`"$X$``!Z*8#"'P@`(!.```````````E<R\E<P```$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z
M.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````+@````````!005)?
M5$5-4```````````4$%27U!23T=.04U%`````#H`````````+P`````````E
M<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````````
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%2
M7T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````
M4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````
M````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.```````````Q`````````&QS965K(&9A:6QE9`````!R96%D(&9A
M:6QE9```````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>`````!P87(M
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````
M<&%R;``````N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`
M````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T`````
M``!54T52`````%5315).04U%``````````!435!$25(``%1%35!$25(`5$5-
M4`````!435```````"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE
M(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B10
M2UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G
M:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I
M>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z
M("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O
M<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@
M/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P
M;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*
M?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T
M:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,
M14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-
M04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*
M<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T
M(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T
M(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A
M9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R
M96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K
M:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F
M(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E
M<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F
M+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@
M)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\
M7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L
M("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D
M;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II
M<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*
M)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@
M)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H
M+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?
M<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M
M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L
M("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R
M;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U
M9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA
M;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4[
M"B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*
M?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I
M<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR
M87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H
M8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE
M(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W
M9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%2
M7R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E
M>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P
M97)L>'-I+F,``````````$-!0TA%`````````````!\`````````'P``````
M```!``````````$`````````_____P````#_____``````$;`SO<````&@``
M`'!U___T!0``<'K__Q`!``"P>___=`$``(!\__^8`0``<'[___`!``!P@?__
M2`(``!""__]H`@``<(+__X@"``"`@___O`(``*"#___0`@``((C__VP#``"`
MB/__C`,``'"*___<`P``8)#__Q0$````D?__-`0``'"1__],!```8)/__XP$
M``"PD___K`0``-"4___@!```X)W__V@%``#0H/__L`4``#"B__\@!@``D+C_
M_V`&```PN?__@`8``#"[___(!@``,+W___0`````````$``````````!>E(`
M!'A!`1L,`0`8````&````#2\__\4`0```$()00!"!D$`````8````#0```!8
M>?__-`$```!%#E";!9\!1IH&09P$0YX"3@E!`$&=`T,107Y2VD'<0=U!WD$&
M04$.`$/?VT$.4)H&FP6<!)T#G@*?`1%!?D;:W-W>!D%"F@:<!)X"0]I!W$'>
M`"````"8````-'K__\0`````1@[0`1%!?I\!8@H.`$,&0=]!"U0```"\````
MX'K___`!````1`Z@`IX"3@H.`$'>00M!"4$`09\!09T#01%!?EJ<!&3<3@K=
M0=]!!D%""TB<!$+<W=\&04$)00!!G`1!G0-!GP%!$4%^``!4````%`$``'A\
M___T`@```$L.L`$107Z:!IL%G`2=`YX"GP$"4`H.`$@&0=_>W=S;VD$+49@(
M09D';`K80=E!"TK8V4*8")D'0]C909@(09D'0]A!V0``'````&P!```@?___
ME`````!&#C`107Z?`5@.`$,&0=\<````C`$``*!___]@`````$4.(!%!?DT.
M`$(&00```#````"L`0``X'___P@!````20Z`(!%!?IT#G@*?`4$.@$!!#J!!
M:PH.`$8&0=_>W4$+```0````X`$``+R`__\8`````````)@```#T`0``R(#_
M_W0$````2PZ`(!%!?IL%G`2?`1%'?Q%(?T$.\")*!6P.5`H.`$<&04$&1T$&
M2-_<VP9L00M"F@9+G@)"E0M#E@I!EPE$F`A!F0="G0,":`K50=9!UT'80=E!
MVD'=0=Y#"P)&U4'60==!V$'90=I!W4'>09H&0=I"E0M!E@I!EPE!F`A!F0=!
MF@9!G0-!G@(``!P```"0`@``K(3__V``````1@XP$4%^GP%+#@!#!D'?3```
M`+`"``#LA/__[`$```!(#H`@$4%^G0.>`D$.T"!)GP%(G`1IW$'?1PH.`$4&
M0=[=1`M(G`2?`4S<0=]#G`2?`47<0=]#G`1!GP$````T``````,``(R&___L
M!0```$L.H`$107Z:!IL%G`2=`YX"GP$#60$*#@!(!D'?WMW<V]I!"P```!P`
M```X`P``1(S__YP`````10YP$4%^6`H.`$(&04$+%````%@#``#$C/__9```
M``!%#B`107X`/````'`#```<C?__\`$```!$#`R`@`0)00!&FP6<!)T#G@*?
M`1%!?D0-`4$.L($$`E4*#@!'!D'?WMW<VT$+`!P```"P`P``S([__TP`````
M10X@$4%^2`X`0@9!````,````-`#``#\CO__(`$```!(#I`!$4%^G0.>`I\!
M5PH.`$4&0=_>W40+0IP$5]Q"G`0``(0````$!```Z(___Q`)````2@[P`Q%!
M?IL%G`2=`YX"GP%MF`A!F0=!F@8"@]A!V4':2`X`2`9!W][=W-M"#O`#F`B9
M!YH&FP6<!)T#G@*?`1%!?DN7"437:=C9VD:8")D'F@9)EPD"?0K70=A!V4':
M00L"H-?8V=I!EPE!F`A!F0=!F@8```!$````C`0``'"8___D`@```$D.H`$1
M07Z<!)T#G@*?`0)C"IL%3`M&"@X`1@9!W][=W$0+20J;!4,+19L%3=M&FP5&
MVT*;!0!`````U`0``!B;__]8`0```$8.@`$107Z?`5H*#@!#!D'?00M"G@)=
M"MY!"T;>00X`1`9!WT$.@`&?`1%!?D&>`@```"@````8!0``=&___Z`"````
M1PZ@`1%!?IX"GP$";@H.`$4&0=_>00L`````/````$0%```(G/__6!8```!+
M#O`%F`B9!YH&FP6<!)T#G@*?`0-[!0H.`$C?WMW<V]K9V$$+00E!`$$107X`
M`!P```"$!0``*++__Y0`````10X@$4%^6`X`1`9!````1````*0%``"HLO__
M^`$```!+#G`107Z7"9@(G`2=`YX"GP%7E@I!F0="F@9!FP56V4':0=M$UDD*
M#@!(!D'?WMW<V-=!"P``+````.P%``!@M/__]`$```!*#E`107Z;!9P$G0.>
M`I\!`F`*#@!'!D'?WMW<VT,+````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/`C````````8",````````!
M`````````,<"`````````0````````#2`@```````!T`````````!@0`````
M```,`````````#@8````````#0`````````T:````````!D`````````(/L!
M```````;``````````@`````````&@`````````H^P$``````!P`````````
M"`````````#U_O]O`````(`"````````!0````````!X#`````````8`````
M````8`,````````*`````````"0$````````"P`````````8`````````!4`
M```````````````````#`````````##]`0```````@````````!`!0``````
M`!0`````````!P`````````7`````````/@2````````````<``````T9P``
M``````,``'`````````````````'`````````*`0````````"`````````!8
M`@````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/G__V\`````#0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````"E!!4BYP;0H``````````"AL````
M````N&@``````````````````*AI````````"&P````````0;````````!AL
M````````(&P``````````````````/!K````````^&L`````````````````
M`#!L````````1T-#.B`H06QP:6YE(#$T+C(N,"D@,30N,BXP```N<VAS=')T
M86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M````````````````````````````````````"P````<````"`````````#@"
M````````.`(````````D````````````````````!```````````````````
M`!X````!`````@````````!<`@```````%P"````````'@``````````````
M``````$````````````````````F````]O__;P(`````````@`(```````"`
M`@```````-P`````````!``````````(````````````````````,`````L`
M```"`````````&`#````````8`,````````8"0````````4````#````"```
M```````8`````````#@````#`````@````````!X#````````'@,````````
M)`0```````````````````$```````````````````!`````!`````(`````
M````H!````````"@$````````%@"````````!``````````(`````````!@`
M````````2@````0```!"`````````/@2````````^!(```````!`!0``````
M``0````1````"``````````8`````````%0````!````!@`````````X&```
M`````#@8````````)`````````````````````0```````````````````!:
M`````0````8`````````8!@```````!@&````````-1/````````````````
M```@````````````````````8`````$````&`````````#1H````````-&@`
M```````D````````````````````!````````````````````&8````!````
M`@````````!@:````````&!H````````D$$``````````````````!``````
M``````````````!N`````0````(`````````\*D```````#PJ0```````-P`
M```````````````````$````````````````````?`````$````"````````
M`-"J````````T*H````````<!@``````````````````"```````````````
M`````(8````.`````P`````````@^P$``````"#[````````"```````````
M``````````@`````````"`````````"2````#P````,`````````*/L!````
M```H^P````````@````````````````````(``````````@`````````G@``
M``8````#`````````##[`0``````,/L``````````@````````4`````````
M"``````````0`````````$\````(`````P`````````P_0$``````##]````
M````T`$```````````````````@`````````"`````````"G`````0````,`
M`````````/\!````````_P```````&@``````````````````````0``````
M``@`````````K`````$````#`````````````@`````````!``````"`````
M````````````````"````````````````````+(````(`````P````````"`
M``(``````(```0``````6`````````````````````@`````````````````
M``"W`````0```#````````````````````"```$``````!P`````````````
M```````!``````````$``````````0````,`````````````````````````
HG``!``````#``````````````````````0``````````````````````
